@@ -1,18 +1,20 @@
-use Convert::ASCII::String q/:all/;
+#!/usr/bin/perl
 
 use strict;
 use warnings;
 
-my $return;
+use Convert::ASCII::String q/:all/;
 
-our $wisdom = 'Premature optimization is the root of all evil.';
+my ($return, $transform);
 
 #$Convert::ASCII::String::sep = '.';
 
-$return = string2ascii(\$wisdom, '.');
+$transform = 'Premature optimization is the root of all evil.';
+
+$return = string2ascii(\$transform, '.');
 
 if ($return == 1) {
-    print "$wisdom\n";
+    print "$transform\n";
 }
 elsif ($return == -1) {
    print "No scalar reference provided.\n";
@@ -20,10 +22,10 @@ elsif ($return == -1) {
 
 <STDIN>;
 
-$return = ascii2string(\$wisdom, '.');
+$return = ascii2string(\$transform, '.');
 
 if ($return == 1) {
-    print "$wisdom\n";
+    print "$transform\n";
 }
 elsif ($return == -1) {
     print "No scalar reference or separator provided.\n";
